@@ -86,7 +86,7 @@ def _api_benchmark_entity(summary_id, context_id, case_id, batch_id, run_id, nam
     }
 
 
-def _api_commit_entity(commit_id, links=True):
+def _api_commit_entity(commit_id, parent_id, links=True):
     result = {
         "author_avatar": "https://avatars.githubusercontent.com/u/878798?v=4",
         "author_login": "dianaclarke",
@@ -103,6 +103,8 @@ def _api_commit_entity(commit_id, links=True):
             "self": "http://localhost/api/commits/%s/" % commit_id,
         },
     }
+    if parent_id:
+        result["links"]["parent"] = "http://localhost/api/commits/%s/" % parent_id
     if not links:
         result.pop("links", None)
     return result
@@ -224,7 +226,7 @@ def _api_context_entity(context_id, links=True):
     return result
 
 
-def _api_history_entity(benchmark_id, case_id, context_id):
+def _api_history_entity(benchmark_id, case_id, context_id, run_name):
     return {
         "benchmark_id": benchmark_id,
         "case_id": case_id,
@@ -238,7 +240,7 @@ def _api_history_entity(benchmark_id, case_id, context_id):
         "sha": "02addad336ba19a654f9c857ede546331be7b631",
         "timestamp": "2021-02-25T01:02:51",
         "message": "ARROW-11771: [Developer][Archery] Move benchmark tests (so CI runs them)",
-        "run_name": "commit: 02addad336ba19a654f9c857ede546331be7b631",
+        "run_name": run_name,
     }
 
 
@@ -259,6 +261,8 @@ def _api_machine_entity(machine_id, links=True):
         "name": "diana",
         "os_name": "macOS",
         "os_version": "10.15.7",
+        "gpu_count": 2,
+        "gpu_product_names": ["Tesla T4", "GeForce GTX 1060 3GB"],
         "links": {
             "list": "http://localhost/api/machines/",
             "self": "http://localhost/api/machines/%s/" % machine_id,
@@ -269,16 +273,20 @@ def _api_machine_entity(machine_id, links=True):
     return result
 
 
-def _api_run_entity(run_id, commit_id, machine_id, now, baseline_id):
+def _api_run_entity(
+    run_id, run_name, commit_id, parent_id, machine_id, now, baseline_id
+):
     result = {
         "id": run_id,
-        "name": "commit: 02addad336ba19a654f9c857ede546331be7b631",
+        "name": run_name,
         "timestamp": now,
-        "commit": _api_commit_entity(commit_id, links=False),
+        "commit": _api_commit_entity(commit_id, parent_id, links=False),
         "machine": _api_machine_entity(machine_id, links=False),
         "links": {
             "list": "http://localhost/api/runs/",
             "self": "http://localhost/api/runs/%s/" % run_id,
+            "commit": "http://localhost/api/commits/%s/" % commit_id,
+            "machine": "http://localhost/api/machines/%s/" % machine_id,
         },
     }
     if baseline_id:
@@ -295,7 +303,10 @@ BENCHMARK_ENTITY = _api_benchmark_entity(
     "some-run-uuid-1",
     "file-write",
 )
-COMMIT_ENTITY = _api_commit_entity("some-commit-uuid-1")
+COMMIT_ENTITY = _api_commit_entity(
+    "some-commit-uuid-1",
+    "some-commit-parent-uuid-1",
+)
 COMPARE_ENTITY = _api_compare_entity(
     ["some-benchmark-uuid-1", "some-benchmark-uuid-2"],
     ["some-batch-uuid-1", "some-batch-uuid-2"],
@@ -345,11 +356,14 @@ HISTORY_ENTITY = _api_history_entity(
     "some-benchmark-uuid-1",
     "some-case-uuid-1",
     "some-context-uuid-1",
+    "some run name",
 )
 MACHINE_ENTITY = _api_machine_entity("some-machine-uuid-1")
 RUN_ENTITY = _api_run_entity(
     "some-run-uuid-1",
+    "some run name",
     "some-commit-uuid-1",
+    "some-parent-commit-uuid-1",
     "some-machine-uuid-1",
     "2021-02-04T17:22:05.225583",
     "some-run-uuid-0",
@@ -357,7 +371,9 @@ RUN_ENTITY = _api_run_entity(
 RUN_LIST = [
     _api_run_entity(
         "some-run-uuid-1",
+        "some run name",
         "some-commit-uuid-1",
+        "some-parent-commit-uuid-1",
         "some-machine-uuid-1",
         "2021-02-04T17:22:05.225583",
         None,
