@@ -1,14 +1,21 @@
 import urllib
 
+import pytest
+
 from ...api._examples import _api_run_entity
+from ...entities._entity import NotFound
+from ...entities.run import Run
 from ...tests.api import _asserts, _fixtures
 from ...tests.helpers import _uuid
 
 
 def _expected_entity(run, baseline_id=None):
+    parent = run.commit.get_parent_commit()
     return _api_run_entity(
         run.id,
+        run.name,
         run.commit_id,
+        parent.id,
         run.machine_id,
         run.timestamp.isoformat(),
         baseline_id,
@@ -23,19 +30,17 @@ class TestRunGet(_asserts.GetEnforcer):
         if baseline:
             # change anything about the context so we get only one baseline
             language = _uuid()
-            contender = _fixtures.create_benchmark_summary(
+            contender = _fixtures.summary(
                 sha=_fixtures.CHILD,
                 language=language,
-                run_id=_uuid(),
             )
-            baseline = _fixtures.create_benchmark_summary(
+            baseline = _fixtures.summary(
                 sha=_fixtures.PARENT,
                 language=language,
-                run_id=_uuid(),
             )
             return contender.run, baseline.run
         else:
-            contender = _fixtures.create_benchmark_summary()
+            contender = _fixtures.summary()
         return contender.run
 
     def test_get_run(self, client):
@@ -50,7 +55,7 @@ class TestRunList(_asserts.ListEnforcer):
     public = True
 
     def _create(self):
-        summary = _fixtures.create_benchmark_summary()
+        summary = _fixtures.summary()
         return summary.run
 
     def test_run_list(self, client):
@@ -76,3 +81,23 @@ class TestRunList(_asserts.ListEnforcer):
         args = urllib.parse.urlencode(args)
         response = client.get(f"/api/runs/?{args}")
         self.assert_200_ok(response, [])
+
+
+class TestRunDelete(_asserts.DeleteEnforcer):
+    url = "api/runs/{}/"
+
+    def test_delete_run(self, client):
+        self.authenticate(client)
+        summary = _fixtures.summary()
+        run_id = summary.run_id
+
+        # can get before delete
+        Run.one(id=run_id)
+
+        # delete
+        response = client.delete(f"/api/runs/{run_id}/")
+        self.assert_204_no_content(response)
+
+        # cannot get after delete
+        with pytest.raises(NotFound):
+            Run.one(id=run_id)
